// The current UTC.
stdout = System.output;
s = "Automatic test is UNSUPPORTED.\n";
stdout.write(s, s.length);

d = new Date();
